@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 __title__ = "MFA for AWS CLI using SafeNet Trusted Access (STA)"
 __homepage__ = 'https://github.com/thalesdemo/sta-awscli'
-__version__ = '2.0.7'
+__version__ = '2.0.8'
 ##########################################################################
 # MFA for AWS CLI using SafeNet Trusted Access (STA)
 ##########################################################################
@@ -46,6 +46,7 @@ import urllib.parse
 import subprocess
 from packaging.version import parse as parse_version
 from requests.exceptions import ConnectionError
+import colorama
 
 try:
     import readline
@@ -131,7 +132,8 @@ def setup_argparser():
             '-r', 
             dest='region',
             nargs='?',
-            const='',
+            default=[],
+            const=True,
             help='Specify any AWS region (without input checking)'
     )
     region_group.add_argument(
@@ -288,11 +290,19 @@ def is_tesseract_installed():
     
     return True
 
+
+def init():
+    # If using Windows, init() will cause anything sent to stdout or stderr
+    # will have ANSI color codes converted to the Windows versions. Hooray!
+    # If you are already using an ANSI compliant shell, it won't do anything
+    colorama.init()
+
+
 ##########################################################################
 # Main function
 
 def main():
-
+    init()
     args = setup_argparser()
     config = configparser.ConfigParser()
 
